# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .mini_chat_settings_data import MiniChatSettingsData


class MiniChatSettingsResponse(UniversalBaseModel):
    """
    Top-level response envelope for GET and PUT.
    """

    data: MiniChatSettingsData

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .failed_operation import FailedOperation


class BulkOperationResponse(UniversalBaseModel):
    """
    Schema for bulk operation response.
    """

    success_count: int = pydantic.Field()
    """
    Number of successful operations
    """

    failure_count: int = pydantic.Field()
    """
    Number of failed operations
    """

    failed_operations: typing.List[FailedOperation] = pydantic.Field()
    """
    Details of failed operations
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .access_level import AccessLevel


class AccessRightGrantRequest(UniversalBaseModel):
    """
    Request schema for granting access rights.
    """

    user_id: str = pydantic.Field()
    """
    User ID to grant access to
    """

    access_level: AccessLevel = pydantic.Field()
    """
    Access level to grant
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ToolParameterResponse(UniversalBaseModel):
    """
    Parameter structure for tool configuration.
    """

    name: str = pydantic.Field()
    """
    Parameter name (e.g., 'sources', 'outputs')
    """

    type: str = pydantic.Field()
    """
    Parameter data type (e.g., 'boolean', 'string', 'integer')
    """

    default: typing.Any
    description: str = pydantic.Field()
    """
    Description of what the parameter controls
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class SessionSpeakerDetail(UniversalBaseModel):
    """
    Speaker stats within a single session.
    """

    speaker: str
    speaking_seconds: float
    speaking_percentage: float
    word_count: int
    segment_count: int
    avg_confidence: float
    words_per_minute: float

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class LiveInteractionResponse(UniversalBaseModel):
    """
    Response for a single live interaction.
    """

    id: str
    session_id: str
    trigger_channel: str
    trigger_text: str
    extracted_request: str
    sender: typing.Optional[str] = None
    response_text: typing.Optional[str] = None
    response_model: typing.Optional[str] = None
    response_tokens_used: typing.Optional[int] = None
    workflow_execution_id: typing.Optional[str] = None
    latency_ms: typing.Optional[int] = None
    status: str
    error_message: typing.Optional[str] = None
    created_at: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class SpeakerInfo(UniversalBaseModel):
    """
    Info about a distinct speaker in a session.
    """

    speaker_key: str
    raw_label: str
    display_name: typing.Optional[str] = None
    segment_count: int
    first_text: str
    total_speaking_seconds: float

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .grant_path_entry_resolved import GrantPathEntryResolved


class StoreAccessEntry(UniversalBaseModel):
    """
    Resolved access to a single vector store.
    """

    store_id: str
    store_name: typing.Optional[str] = None
    access_level: str
    grant_paths: typing.Optional[typing.List[GrantPathEntryResolved]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
